@@ -1,11 +1,11 @@
 /* GeneralController.m
  * Preferences module for general settings
  *
- * Copyright (C) 1996-2011 by vhf interservice GmbH
+ * Copyright (C) 1996-2005 by vhf interservice GmbH
  * Author:   Georg Fleischmann
  *
  * Created:  1999-03-15
- * Modified: 2011-03-30 (switch to turn off automatic update check)
+ * Modified: 2005-11-11 (activated cache switch for Apple)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the vhf Public License as
@@ -27,7 +27,7 @@
  */
 
 #include <AppKit/AppKit.h>
-#include <VHFShared/VHFStringAdditions.h>	// +stringWithFloat:
+#include <VHFShared/vhfCommonFunctions.h>
 #include "GeneralController.h"
 #include "../NotificationNames.h"
 
@@ -119,17 +119,16 @@
 //#ifdef __APPLE__
 //    [[switchMatrix cellAtRow:SWITCH_DISABLECACHE column:0] setState:1];
 //#else
-    [[switchMatrix cellAtRow:SWITCH_DISABLECACHE        column:0] setState:([[defaults objectForKey:@"doCaching"]           isEqual:@"YES"]) ? 0 : 1];
+    [[switchMatrix cellAtRow:SWITCH_DISABLECACHE column:0] setState:([[defaults objectForKey:@"doCaching"] isEqual:@"YES"]) ? 0 : 1];
 //#endif
-    [[switchMatrix cellAtRow:SWITCH_EXPERT              column:0] setState:([[defaults objectForKey:@"expertMode"]          isEqual:@"YES"]) ? 1 : 0];
-    [[switchMatrix cellAtRow:SWITCH_REMOVEBACKUPS       column:0] setState:([[defaults objectForKey:@"removeBackups"]       isEqual:@"YES"]) ? 1 : 0];
-    [[switchMatrix cellAtRow:SWITCH_SELECTNONEDIT       column:0] setState:([[defaults objectForKey:@"selectNonEditable"]   isEqual:@"YES"]) ? 1 : 0];
-    [[switchMatrix cellAtRow:SWITCH_SELECTBYBORDER      column:0] setState:([[defaults objectForKey:@"selectByBorder"]      isEqual:@"YES"]) ? 1 : 0];
+    [[switchMatrix cellAtRow:SWITCH_EXPERT column:0] setState:([[defaults objectForKey:@"expertMode"] isEqual:@"YES"]) ? 1 : 0];
+    [[switchMatrix cellAtRow:SWITCH_REMOVEBACKUPS column:0] setState:([[defaults objectForKey:@"removeBackups"] isEqual:@"YES"]) ? 1 : 0];
+    [[switchMatrix cellAtRow:SWITCH_SELECTNONEDIT column:0] setState:([[defaults objectForKey:@"selectNonEditable"] isEqual:@"YES"]) ? 1 : 0];
+    [[switchMatrix cellAtRow:SWITCH_SELECTBYBORDER column:0] setState:([[defaults objectForKey:@"selectByBorder"] isEqual:@"YES"]) ? 1 : 0];
 
 #if defined(GNUSTEP_BASE_VERSION) || defined(__APPLE__)
-    [[switchMatrix cellAtRow:SWITCH_DISABLEANTIALIAS    column:0] setState:([[defaults objectForKey:@"disableAntiAliasing"] isEqual:@"YES"]) ? 1 : 0];
-    [[switchMatrix cellAtRow:SWITCH_OSPROPERTYLIST      column:0] setState:([[defaults objectForKey:@"writeOSPropertyList"] isEqual:@"YES"]) ? 1 : 0];
-    [[switchMatrix cellAtRow:SWITCH_DISABLEAUTOUPDATE   column:0] setState:([[defaults objectForKey:@"disableAutoUpdate"]   isEqual:@"YES"]) ? 1 : 0];
+    [[switchMatrix cellAtRow:SWITCH_DISABLEANTIALIAS column:0] setState:([[defaults objectForKey:@"disableAntiAliasing"] isEqual:@"YES"]) ? 1 : 0];
+    [[switchMatrix cellAtRow:SWITCH_OSPROPERTYLIST column:0] setState:([[defaults objectForKey:@"writeOSPropertyList"] isEqual:@"YES"]) ? 1 : 0];
 #endif
 
     /* snap */
@@ -145,10 +144,7 @@
     [unitPopup setAction:@selector(setUnit:)];
 
     /* line width */
-    [lineWidthField setStringValue:[NSString stringWithFloat:[[defaults objectForKey:@"lineWidth"] floatValue]]];
-
-    /* window grid */
-    [windowGridField setIntValue:[defaults integerForKey:@"windowGrid"]];
+    [lineWidthField setStringValue:vhfStringWithFloat([[defaults objectForKey:@"lineWidth"] floatValue])];
 
     /* cache size */
     [cacheLimitField setIntValue:[[defaults objectForKey:@"cacheLimit"] intValue]];
@@ -158,8 +154,8 @@
 
 
 - (void)set:sender;
-{   NSString    *string;
-    id          defaults = [NSUserDefaults standardUserDefaults];
+{   NSString	*string;
+    id		defaults = [NSUserDefaults standardUserDefaults];
 
     /* caching */
 //#ifdef __APPLE__
@@ -192,12 +188,8 @@
 #if defined(GNUSTEP_BASE_VERSION) || defined(__APPLE__)
     string = ([[switchMatrix cellAtRow:SWITCH_DISABLEANTIALIAS column:0] state]) ? @"YES" : @"NO";
     [defaults setObject:string forKey:@"disableAntiAliasing"];
-
     string = ([[switchMatrix cellAtRow:SWITCH_OSPROPERTYLIST column:0] state]) ? @"YES" : @"NO";
     [defaults setObject:string forKey:@"writeOSPropertyList"];
-
-    string = ([[switchMatrix cellAtRow:SWITCH_DISABLEAUTOUPDATE column:0] state]) ? @"YES" : @"NO";
-    [defaults setObject:string forKey:@"disableAutoUpdate"];
 #endif
 
     /* snap */
@@ -206,15 +198,10 @@
     	[defaults setObject:string forKey:@"snap"];
 
     /* line width */
-    string = [NSString stringWithFloat:[lineWidthField floatValue]];
+    string = vhfStringWithFloat([lineWidthField floatValue]);
     if ( ![string isEqual:[defaults objectForKey:@"lineWidth"]] )
         [defaults setObject:string forKey:@"lineWidth"];
 
-    /* window grid */
-    if ( [windowGridField intValue] != [defaults integerForKey:@"windowGrid"] )
-        [defaults setObject:[NSNumber numberWithInt:[windowGridField intValue]]
-                     forKey:@"windowGrid"];
-
     /* cache limit */
     if (cacheLimitField)
     {
