@@ -5,7 +5,7 @@
  * Author:   Georg Fleischmann
  *
  * created:  1996-01-25
- * modified: 2005-06-10
+ * modified: 2005-11-13 (new: vhfPathWithPathComponents())
  *
  * This file is part of the vhf Shared Library.
  *
@@ -156,7 +156,7 @@ NSString *vhfLocalLibrary(NSString* append)
         return sPath;
     return lPath;
 #else	// OpenStep
-    return [NSString stringWithFormat:@"/LocalLibrary/%@", append];
+    return vhfPathWithPathComponents(@"/LocalLibrary", append, nil);
 #endif
 }
 NSString *vhfUserLibrary(NSString* append)
@@ -165,10 +165,11 @@ NSString *vhfUserLibrary(NSString* append)
     return [[NSSearchPathForDirectoriesInDomains(NSLibraryDirectory, NSUserDomainMask, YES) objectAtIndex:0]
             stringByAppendingPathComponent:append];
 #else	// OpenStep
-    return [NSString stringWithFormat:@"%@Library/%@", vhfHomeDirectory(), append];
+    return vhfPathWithPathComponents(NSHomeDirectory(), @"Library", append, nil);
 #endif
 }
-/* return "path/" instead of "path"
+/* return "path/" instead of "path" ()
+ * deprecated !, use vhfPathWithPathComponents(NSHomeDirectory(), ...)
  */
 NSString *vhfHomeDirectory(void)
 {
@@ -177,6 +178,25 @@ NSString *vhfHomeDirectory(void)
     return [NSString stringWithFormat:@"%@/", NSHomeDirectory()];
 }
 
+/* build complete path from single path components.
+ * the path components are separated with path separators.
+ * parameter: nil terminated list of path components
+ * created: 2005-11-13
+ */
+NSString *vhfPathWithPathComponents(NSString *seg1, ...)
+{   va_list	arg_p;
+    void	*arg;
+    NSString	*path = seg1;
+
+    va_start(arg_p, seg1);
+    while ( (arg = va_arg(arg_p, void*)) != nil )
+    {
+        path = [path stringByAppendingPathComponent:arg];
+    }
+    va_end(arg_p);
+    return path;
+}
+
 #if 0
 /* scan up to sequence
  * a sequence is separated by space
